pub struct PlayerCapabilityFlags(/* private fields */);Implementations
Sourceimpl PlayerCapabilityFlags
impl PlayerCapabilityFlags
Sourcepub const PLAY: PlayerCapabilityFlags
pub const PLAY: PlayerCapabilityFlags
If set, the player can Play().
Sourcepub const PAUSE: PlayerCapabilityFlags
pub const PAUSE: PlayerCapabilityFlags
If set, the player can Pause().
Sourcepub const SEEK: PlayerCapabilityFlags
pub const SEEK: PlayerCapabilityFlags
If set, the player can Seek().
Sourcepub const SKIP_FORWARD: PlayerCapabilityFlags
pub const SKIP_FORWARD: PlayerCapabilityFlags
If set, the player can SkipForward().
Sourcepub const SKIP_REVERSE: PlayerCapabilityFlags
pub const SKIP_REVERSE: PlayerCapabilityFlags
If set, the player can SkipReverse().
Sourcepub const SHUFFLE: PlayerCapabilityFlags
pub const SHUFFLE: PlayerCapabilityFlags
If set, the player can shuffle media.
pub const CHANGE_TO_NEXT_ITEM: PlayerCapabilityFlags
pub const CHANGE_TO_PREV_ITEM: PlayerCapabilityFlags
Sourcepub const HAS_GAIN_CONTROL: PlayerCapabilityFlags
pub const HAS_GAIN_CONTROL: PlayerCapabilityFlags
If set, the player can BindGainControl().
Sourcepub const REPEAT_GROUPS: PlayerCapabilityFlags
pub const REPEAT_GROUPS: PlayerCapabilityFlags
If set, the player can repeat groups.
Sourcepub const REPEAT_SINGLE: PlayerCapabilityFlags
pub const REPEAT_SINGLE: PlayerCapabilityFlags
If set, the player can repeat single media items.
Sourcepub const SET_PLAYBACK_RATE: PlayerCapabilityFlags
pub const SET_PLAYBACK_RATE: PlayerCapabilityFlags
If set, the player can accept playback rate changes.
Sourceimpl PlayerCapabilityFlags
impl PlayerCapabilityFlags
Sourcepub const fn empty() -> PlayerCapabilityFlags
pub const fn empty() -> PlayerCapabilityFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> PlayerCapabilityFlags
pub const fn all() -> PlayerCapabilityFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<PlayerCapabilityFlags>
pub const fn from_bits(bits: u32) -> Option<PlayerCapabilityFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> PlayerCapabilityFlags
pub const fn from_bits_truncate(bits: u32) -> PlayerCapabilityFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> PlayerCapabilityFlags
pub const fn from_bits_retain(bits: u32) -> PlayerCapabilityFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<PlayerCapabilityFlags>
pub fn from_name(name: &str) -> Option<PlayerCapabilityFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: PlayerCapabilityFlags) -> bool
pub const fn intersects(&self, other: PlayerCapabilityFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: PlayerCapabilityFlags) -> bool
pub const fn contains(&self, other: PlayerCapabilityFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: PlayerCapabilityFlags)
pub fn insert(&mut self, other: PlayerCapabilityFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: PlayerCapabilityFlags)
pub fn remove(&mut self, other: PlayerCapabilityFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: PlayerCapabilityFlags)
pub fn toggle(&mut self, other: PlayerCapabilityFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: PlayerCapabilityFlags, value: bool)
pub fn set(&mut self, other: PlayerCapabilityFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: PlayerCapabilityFlags,
) -> PlayerCapabilityFlags
pub const fn intersection( self, other: PlayerCapabilityFlags, ) -> PlayerCapabilityFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: PlayerCapabilityFlags) -> PlayerCapabilityFlags
pub const fn union(self, other: PlayerCapabilityFlags) -> PlayerCapabilityFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(
self,
other: PlayerCapabilityFlags,
) -> PlayerCapabilityFlags
pub const fn difference( self, other: PlayerCapabilityFlags, ) -> PlayerCapabilityFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: PlayerCapabilityFlags,
) -> PlayerCapabilityFlags
pub const fn symmetric_difference( self, other: PlayerCapabilityFlags, ) -> PlayerCapabilityFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> PlayerCapabilityFlags
pub const fn complement(self) -> PlayerCapabilityFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl PlayerCapabilityFlags
impl PlayerCapabilityFlags
Sourcepub const fn iter(&self) -> Iter<PlayerCapabilityFlags> ⓘ
pub const fn iter(&self) -> Iter<PlayerCapabilityFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<PlayerCapabilityFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<PlayerCapabilityFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.