PlayerStatus

Struct PlayerStatus 

pub struct PlayerStatus {
    pub duration: Option<i64>,
    pub player_state: Option<PlayerState>,
    pub timeline_function: Option<TimelineFunction>,
    pub repeat_mode: Option<RepeatMode>,
    pub shuffle_on: Option<bool>,
    pub content_type: Option<ContentType>,
    pub error: Option<Error>,
    pub is_live: Option<bool>,
    /* private fields */
}
Status of a media player.

Fields

duration: Option<i64>

Total duration of playing media.

If this value is omitted, the duration is unknown, not applicable or unchanged. Initially, the duration is assumed to be unknown.

player_state: Option<PlayerState>

State of the player.

If this field is omitted, the value is unchanged. Initially, the value is IDLE.

timeline_function: Option<TimelineFunction>

A playback function that describes the position and rate of play through the media as a function of CLOCK_MONOTONIC.

If this field is omitted, the value is unchanged. Initially, reference_delta is 1 and the remaining constituent fields are 0.

repeat_mode: Option<RepeatMode>

Repeat mode of the player.

If this field is omitted, the value is unchanged. Initially, the value is NONE.

shuffle_on: Option<bool>

Shuffle mode of the player.

If this field is omitted, the value is unchanged. Initially, the value is false.

content_type: Option<ContentType>

The type of content playing back.

If this field is omitted, the value is unchanged. Initially, the value is OTHER.

error: Option<Error>

An error the player may have encountered.

This field is omitted unless there is an error. Once an error is indicated, it cannot be rescinded.

is_live: Option<bool>

Whether the playing media is live (such as television or a live stream).

If this field is omitted, the value is unchanged. Initially, the value is false.