SessionInfoDelta

Struct SessionInfoDelta 

pub struct SessionInfoDelta {
    pub domain: Option<String>,
    pub is_local: Option<bool>,
    pub is_locally_active: Option<bool>,
    pub player_status: Option<PlayerStatus>,
    pub metadata: Option<Metadata>,
    pub media_images: Option<Vec<MediaImage>>,
    pub player_capabilities: Option<PlayerCapabilities>,
    /* private fields */
}
SessionInfoDelta holds a description of a media session.

Fields

domain: Option<String>

The domain on which the session takes place. A domain identifies a set of mutually compatible media targets and sessions; sessions on a domain may be played back on targets of the same domain.

This field is always present.

is_local: Option<bool>

Whether the source of the media playback is on this device.

This field is present only if known.

is_locally_active: Option<bool>

If this is true, the playback is taking place local to the device. Playing on the device speaker is local, playing on a remote speaker is not. This is only set when the session is playing back; a paused session is not active.

This field is always present.

player_status: Option<PlayerStatus>

The status of the player.

This field is always present.

metadata: Option<Metadata>

Metadata describing the media session.

This field is always present.

media_images: Option<Vec<MediaImage>>

Images associated with the media or its source.

This field is always present.

player_capabilities: Option<PlayerCapabilities>

The capabilities the player of the media implements.

This field is always present.